summaryrefslogtreecommitdiff
path: root/libjava/java/net/ContentHandlerFactory.java
diff options
context:
space:
mode:
authorMichael Koch <konqueror@gmx.de>2003-05-25 11:40:19 +0000
committerMichael Koch <mkoch@gcc.gnu.org>2003-05-25 11:40:19 +0000
commitc7684ffe55c75b893fe40988dbb8fcea9beae3ba (patch)
tree88ef0760e764ef489e276334b8e20f71e9f96390 /libjava/java/net/ContentHandlerFactory.java
parenteceea3010ff9d19a48d650e5dccb7105d66adbd2 (diff)
PushbackInputStream.java, [...]: Merged new versions from classpath.
2003-05-25 Michael Koch <konqueror@gmx.de> * java/io/PushbackInputStream.java, java/net/Authenticator.java, java/net/ContentHandler.java, java/net/ContentHandlerFactory.java, java/net/DatagramSocket.java, java/net/DatagramSocketImpl.java, java/net/DatagramSocketImplFactory.java, java/net/FileNameMap.java, java/net/SocketImplFactory.java, java/net/SocketOptions.java, java/net/URLStreamHandlerFactory.java: Merged new versions from classpath. From-SVN: r67165
Diffstat (limited to 'libjava/java/net/ContentHandlerFactory.java')
-rw-r--r--libjava/java/net/ContentHandlerFactory.java27
1 files changed, 13 insertions, 14 deletions
diff --git a/libjava/java/net/ContentHandlerFactory.java b/libjava/java/net/ContentHandlerFactory.java
index d954f9ad440..04fa3f11945 100644
--- a/libjava/java/net/ContentHandlerFactory.java
+++ b/libjava/java/net/ContentHandlerFactory.java
@@ -1,5 +1,5 @@
/* ContentHandlerFactory.java -- Interface for creating content handlers
- Copyright (C) 1998, 1999, 2000, 2001 Free Software Foundation, Inc.
+ Copyright (C) 1998, 1999, 2000, 2001, 2003 Free Software Foundation, Inc.
This file is part of GNU Classpath.
@@ -45,25 +45,24 @@ package java.net;
*/
/**
- * This interface maps MIME types to ContentHandler objects. It consists
- * of one method that, when passed a MIME type, returns a handler for that
- * type.
+ * This interface maps MIME types to <code>ContentHandler</code> objects.
+ * It consists of one method that, when passed a MIME type, returns a
+ * handler for that type.
*
* @author Aaron M. Renn (arenn@urbanophile.com)
* @author Warren Levy <warrenl@cygnus.com>
*/
public interface ContentHandlerFactory
{
-/**
- * This method is passed a MIME type as a string and is responsible for
- * returning the appropriate ContentType object.
- *
- * @param mime_type The MIME type to map to a ContentHandler
- *
- * @return The ContentHandler for the passed in MIME type
- */
-ContentHandler
-createContentHandler(String mime_type);
+ /**
+ * This method is passed a MIME type as a string and is responsible for
+ * returning the appropriate <code>ContentHandler</code> object.
+ *
+ * @param mimeType The MIME type to map to a <code>ContentHandler</code>
+ *
+ * @return The <code>ContentHandler</code> for the passed in MIME type
+ */
+ public ContentHandler createContentHandler(String mimeType);
} // interface ContentHandlerFactory